import { ActionTask } from "./ActionTask";
import { DefaultEvent, EventHook, Machine } from "./types";
/**
 * ## The executor for protocols.
 * Note: Thread safety not tested. Execution in multi-threaded environment
 *       may cause undefined behaviors.
 *
 */
export declare class ProtocolExecutor {
    /**
     * init hooks registered
     */
    private _initHooks;
    /**
     * init hooks registered
     */
    private _startHooks;
    /**
     * all nodes in the protocol
     */
    private _nodes;
    /**
     * stopped?
     */
    private _shutdown;
    /**
      * The global event accept promise , for serialization
      */
    private _acceptPromise;
    /**
      * The global event complete  promise , for serialization
      */
    private _completePromise;
    /**
     * construct from Machine
     */
    constructor(machine: Machine);
    /**
     * get the all the event signatures , which is in format:
     *   node_name:action_name:tag
     * where
     *   - node_name   name of this node
     *   - event_name  name of this event
     *   - tag         if positive '+' else '-'
     */
    getEvents(): string[];
    /**
      * Issue the event and get a task object which indicates the progress
      * @param event the event to be issued
      * @returns the task created for this issue
      *
      * @see getEvents
      */
    issueEvent(event: DefaultEvent): ActionTask;
    /**
      * register a hook to be triggered when event is issued
      * @param event which event to be register on
      *
      * @see getEvents
      * @see issueEvent
      */
    registerHook(event: DefaultEvent, hook: EventHook): void;
    /**
     * init, just call init hooks now
     */
    init(): void;
    /**
     * start, just call start hooks now
     */
    start(): void;
    shutdown(): void;
    private getAction;
    private promiseCompose;
}
