import { Node } from "./Node";
import { DefaultEvent, EventHook, Jump } from "./types";
/**
 * Action represents Jump in the protocol. You can register hooks to this action/jump,
 * which will be invoked once event triggered
 * @see {@link ProtocolExecutor#registerHook}
 * @see {@link ProtocolExecutor#issueEvent}
 */
export declare class Action {
    /**
     * name
     */
    private _name;
    /**
     * from state name
     */
    private _start;
    /**
     * target state name
     */
    private _end;
    /**
     * The registered hook
     * @see {@link ProtocolExecutor#registerHook}
     */
    private _hook;
    private _node;
    /**
     * whether this event can be issued via {@link ProtocolExecutor.issueEvent }
     * If not, this event can only be triggered as cascades of other action
     */
    private _positive;
    /**
     * The cascaded actions to be triggered when this action is triggered.
     */
    private _cascades;
    private _cascadeNames;
    constructor(jump: Jump, node: Node);
    get name(): string;
    get positive(): boolean;
    get start(): string;
    set cascadeNames(names: string[]);
    get cascadeNames(): string[];
    set cascades(cascades: Action[]);
    set hook(hook: EventHook);
    /**
     * Whether the action can be triggered now
     */
    acceptable(): boolean;
    /**
     * Execute the event related hooks registered via registerHook
     * @param event The event issued via {@link ProtocolExecutor#issueEvent}
     */
    doAction(event: DefaultEvent): void;
}
